@@ -1,5 +1,7 @@
 """
-Main interface for sagemaker-a2i-runtime service literal definitions.
+Type annotations for sagemaker-a2i-runtime service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_a2i_runtime/literals.html)
 
 Usage::
 
